aboutsummaryrefslogtreecommitdiff
path: root/lib/VNLib.Data.Caching.ObjectCache/src/IBlobCache.cs
diff options
context:
space:
mode:
Diffstat (limited to 'lib/VNLib.Data.Caching.ObjectCache/src/IBlobCache.cs')
-rw-r--r--lib/VNLib.Data.Caching.ObjectCache/src/IBlobCache.cs6
1 files changed, 2 insertions, 4 deletions
diff --git a/lib/VNLib.Data.Caching.ObjectCache/src/IBlobCache.cs b/lib/VNLib.Data.Caching.ObjectCache/src/IBlobCache.cs
index bc3180b..7333898 100644
--- a/lib/VNLib.Data.Caching.ObjectCache/src/IBlobCache.cs
+++ b/lib/VNLib.Data.Caching.ObjectCache/src/IBlobCache.cs
@@ -25,8 +25,6 @@
using System;
using System.Collections.Generic;
-using VNLib.Utils.Memory;
-
namespace VNLib.Data.Caching.ObjectCache
{
/// <summary>
@@ -40,9 +38,9 @@ namespace VNLib.Data.Caching.ObjectCache
public uint BucketId { get; }
/// <summary>
/// The internal heap used to allocate <see cref="CacheEntry"/> buffers
/// </summary>
- IUnmangedHeap CacheHeap { get; }
+ ICacheEntryMemoryManager MemoryManager { get; }
/// <summary>
/// Attempts to retreive the entry at the given id.
@@ -40,9 +38,9 @@ namespace VNLib.Data.Caching.ObjectCache
public uint BucketId { get; }
/// <summary>
- /// The internal heap used to allocate <see cref="CacheEntry"/> buffers
+ /// The memory manager used to create <see cref="CacheEntry"/> memory handles
/// </summary>